import React, { useEffect, useState } from "react";
import { useSelector } from "react-redux";

import { getProjects } from "@redux/projectsTrackerSlice";

import { caseOfNum } from "@utils/helper";

import { Loader } from "@components/Common/Loader/Loader";

import archiveTrackerProjects from "assets/icons/archiveTrackerProjects.svg";
import arrowViewReport from "assets/icons/arrows/arrowViewReport.svg";
import search from "assets/icons/serchIcon.png";
import mockAvatar from "assets/images/avatarMok.png";

import ArchiveTableTracker from "../ArchiveTableTracker/ArchiveTableTracker";
import "./archive.scss";

const Archive = ({
  loader,
  allCompletedTasks,
  projects,
  filterCompleteTasks,
  setFilterCompleteTasks
}) => {
  function filterArchiveTasks(e) {
    setFilterCompleteTasks(
      allCompletedTasks.filter((item) => {
        if (!e.target.value) {
          return item;
        }
        if (
          item?.title.toLowerCase().startsWith(e.target.value.toLowerCase()) ||
          item?.description
            .toLowerCase()
            .startsWith(e.target.value.toLowerCase())
        ) {
          return item;
        }
      })
    );
  }

  return (
    <>
      <div className="archive__tasks">
        <div className="archive__title">
          <h3>Архив задач:</h3>
          <p>
            {`${filterCompleteTasks.length} 
          ${caseOfNum(filterCompleteTasks.length, "tasks")}`}
          </p>

          <div className="archive__tasks-period">
            <div className="buttons-month">
              <button>
                <img src={arrowViewReport} alt="<"></img>
              </button>
              <button>
                <img src={arrowViewReport} alt=">"></img>
              </button>
            </div>
            <div className="month-period">
              <h2>Сентябрь,</h2>
              <h3>2023</h3>
            </div>
          </div>
          <div className="archive__tasks__search">
            <img src={search} alt="search" />
            <input
              type="text"
              placeholder="Найти задачу"
              onChange={(event) => filterArchiveTasks(event)}
            />
          </div>
        </div>

        {loader && <Loader style="green" />}

        <ArchiveTableTracker
          loader={loader}
          filterCompleteTasks={filterCompleteTasks}
        />
      </div>
      <div className="archive__projects">
        <div className="archive__projects-title">
          <h3>Архив проектов:</h3>
          <p>
            {`${projects?.filter((project) => project.status === 10).length} 
           ${caseOfNum(
             projects?.filter((project) => project.status === 10).length,
             "projects"
           )}`}
          </p>
        </div>
        <div className="archive__tasksWrapper">
          {Boolean(
            projects?.filter((project) => project.status === 10).length
          ) ? (
            projects?.map((project, index) => {
              return project.status === 10 ? (
                <div className="archive__completeTask-project" key={index}>
                  <div className="archive__completeTask__description">
                    <p className="project-title-archive">{project.name}</p>
                    <p className="date">{project.date}</p>
                  </div>
                  <div className="archive__completeTask__creator">
                    <img src={mockAvatar} alt="#" />
                    <div className="creator-title">
                      <h4>Создатель проекта:</h4>
                      <p>{"Василий Тарасов"}</p>
                    </div>
                  </div>
                </div>
              ) : (
                ""
              );
            })
          ) : (
            <div className="archive__noItem-project">
              <img src={archiveTrackerProjects} alt="#" />
              <p>В архиве проектов нет</p>
            </div>
          )}
        </div>
      </div>
    </>
  );
};

export default Archive;
